--
-- InteractiveButtons
-- Specialization for an interactive control button
--
-- @author  	Manuel Leithner (SFM-Modding)
-- @version 	v2.1
-- @date  		29/08/11
-- @history:	v1.0 - Initial version
--				v2.0 - converted to ls2011
--				v2.1 - improvements
--
-- free for noncommerical-usage
--

InteractiveButtons = {};

function InteractiveButtons.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(InteractiveControl, specializations);
end;

function InteractiveButtons:load(xmlFile)

	local i=0;
	while true do
		local buttonName = string.format("vehicle.interactiveComponents.buttons.button(%d)", i);	
		if not hasXMLProperty(xmlFile, buttonName) then
			break;
		end;
		local name = Utils.getNoNil(g_i18n:getText(getXMLString(xmlFile, buttonName .. "#name")), "ERROR");
		local mark = Utils.indexToObject(self.components, getXMLString(xmlFile, buttonName .. "#mark"));
		local highlight = getChildAt(mark, 0);
		local size = Utils.getNoNil(getXMLFloat(xmlFile, buttonName .. "#size"), 0.1);
		local event = getXMLString(xmlFile, buttonName .. "#event");
		local onMessage = g_i18n:getText(Utils.getNoNil(getXMLString(xmlFile, buttonName .. "#onMessage"), "ic_button_on"));
		local offMessage =  g_i18n:getText(Utils.getNoNil(getXMLString(xmlFile, buttonName .. "#offMessage") , "ic_button_off"));
	
		local button = Button:new(nil, highlight, name, mark, size, event, self, onMessage, offMessage, self.infoBar);
		
		button.synch = Utils.getNoNil(getXMLBool(xmlFile, buttonName .. "#synch"), true);

		table.insert(self.interactiveObjects, button);
		i = i + 1;
	end;
end;

function InteractiveButtons:delete()
end;

function InteractiveButtons:mouseEvent(posX, posY, isDown, isUp, button)
end;

function InteractiveButtons:keyEvent(unicode, sym, modifier, isDown)
end;

function InteractiveButtons:update(dt)	
end;

function InteractiveButtons:draw()
end;



--
-- Button Class
-- Specifies an interactive Button
--
-- SFM-Modding
-- @author  Manuel Leithner
-- @date  29/08/11
--

Button = {};

function Button:new(node, highlight, name, mark, size, event, vehicle, onMessage, offMessage, infobar)

	local Button_mt = Class(Button, InteractiveComponentInterface);	
    local instance = InteractiveComponentInterface:new(node, highlight, name, mark, size, onMessage, offMessage, infobar, Button_mt);

	instance.vehicle = vehicle;
	instance.event = event;
	
	return instance;	
end;

function Button:delete()
	InteractiveComponentInterface.delete(self);
end;

function Button:mouseEvent(posX, posY, isDown, isUp, button)
	InteractiveComponentInterface.mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function Button:keyEvent(unicode, sym, modifier, isDown)
	InteractiveComponentInterface.keyEvent(self, unicode, sym, modifier, isDown);
end;

function Button:update(dt)
	if self.vehicle ~= nil then
		if self.event == "toggleBeaconLights" then
			self.isOpen = self.vehicle.beaconLightsActive;
		elseif self.event == "toggleWarningLights" then
			self.isOpen = self.vehicle.rLights.blw.a;
		elseif self.event == "toggleLight" then
			self.isOpen = self.vehicle.lightsState ~= 0;
		elseif self.event == "toggleFrontWorklights" then		
			self.isOpen = self.vehicle.B3["work"][2].a;
		elseif self.event == "toggleBackWorklights" then
			self.isOpen = self.vehicle.B3["work"][5].a;
		elseif self.event == "toggleLeftWorklights" then		
			self.isOpen = self.vehicle.B3["work"][3].a;
		elseif self.event == "toggleRightWorklights" then
			self.isOpen = self.vehicle.B3["work"][4].a;
		elseif self.event == "toggleRightIndicator" then		
			self.isOpen = self.vehicle.rLights.blr.a;
		elseif self.event == "toggleLeftIndicator" then
			self.isOpen = self.vehicle.rLights.bll.a;
		elseif self.event == "togglePress" then		
			self.isOpen = self.vehicle.B3["strobe"][1];
		elseif self.event == "toggleSosi" then		
			self.isOpen = self.vehicle.B3["strobe"][1].a;
		elseif self.event == "toggleFrontBeacon" then
			self.isOpen = self.vehicle.B3["strobe"][1].a;
			self.isOpen = self.vehicle.B3["strobe"][2].a;
		end;
	end;
--	if self.vehicle ~= nil then
--		if self.event == "toggleMotorIgnition" then		
--			self.isOpen = self.vehicle.isMotorStarted;
--		end;
--	end;
	
	local i = 1;
	local j = 2;
	local k = 3;
	local l = 4;
	local m = 5;
	
--	if self.isClient then
--			if self.vehicle.B3.strobe[1].a == false then
--				if InputBinding.hasEvent(InputBinding.Blaulicht) then
--					self.vehicle:setState("strobe:"..i, true);
--					self.vehicle:setState("strobe:"..j, true);
--					self.vehicle:setState("strobe:"..k, true);
--					self.vehicle:setState("strobe:"..l, true);
--					self.vehicle:setState("strobe:"..m, true);
--				else
--					self.vehicle:setState("strobe:"..i, false);
--					self.vehicle:setState("strobe:"..j, false);
--					self.vehicle:setState("strobe:"..k, false);
--					self.vehicle:setState("strobe:"..l, false);
--					self.vehicle:setState("strobe:"..m, false);
--				end;
--			end;
--	end;
	
	InteractiveComponentInterface.update(self, dt);
end;

function Button:draw()
	InteractiveComponentInterface.draw(self);
end;

function Button:doAction(noEventSend, forceAction)
	if self.event == "toggleBeaconLights" then
			if self.vehicle ~= nil then
			local i = 1;
			local j = 2;
			local k = 3;
			local l = 4;
			local m = 5;
			if self.vehicle.B3.strobe[i].a then
				self.vehicle:setState("strobe:"..i, false);
				self.vehicle:setState("strobe:"..j, false);
				self.vehicle:setState("strobe:"..k, false);
				self.vehicle:setState("strobe:"..l, false);
				self.vehicle:setState("strobe:"..m, false);
			else
				self.vehicle:setState("strobe:"..i, true);
				self.vehicle:setState("strobe:"..j, true);
				self.vehicle:setState("strobe:"..k, true);
				self.vehicle:setState("strobe:"..l, true);
				self.vehicle:setState("strobe:"..m, true);
			end;
			
		end;
	end;
	
		if self.event == "toggleWarningLights" then
			if self.vehicle ~= nil then
				if self.vehicle.rLights.blw.a then
					self.vehicle:setBlinkerWState(false);
					self.vehicle:setBlinkerLState(false);
					self.vehicle:setBlinkerRState(false);
				else
					self.vehicle:setBlinkerWState(true);
					self.vehicle:setBlinkerLState(true);
					self.vehicle:setBlinkerRState(true);
				end;
			end;
		end;	
	if self.event == "toggleFrontWorklights" then
		if self.vehicle ~= nil then
			local i = 2;
			if self.vehicle.B3.work[i].a then
				self.vehicle:setState("work:"..i, false);
			else
				self.vehicle:setState("work:"..i, true);
			end;
		end;
	end;
	
	if self.event == "toggleLight" then
			if self.vehicle ~= nil then
				Steerable.setNextLightsState(self.vehicle);
			end;
	end;
	if self.event == "toggleBackWorklights" then
		if self.vehicle ~= nil then
			local i = 5;
			if self.vehicle.B3.work[i].a then
				self.vehicle:setState("work:"..i, false);
			else
				self.vehicle:setState("work:"..i, true);
			end;
		end;
	end;
	if self.event == "toggleLeftWorklights" then
		if self.vehicle ~= nil then
			local i = 3;
			if self.vehicle.B3.work[i].a then
				self.vehicle:setState("work:"..i, false);
			else
				self.vehicle:setState("work:"..i, true);
			end;
		end;
	end;
	if self.event == "toggleRightWorklights" then
		if self.vehicle ~= nil then
			local i = 4;
			if self.vehicle.B3.work[i].a then
				self.vehicle:setState("work:"..i, false);
			else
				self.vehicle:setState("work:"..i, true);
			end;
		end;
	end;
	
	if self.event == "toggleRightIndicator" then
		if self.vehicle ~= nil then
			if not self.vehicle.rLights.blw.a then
				if self.vehicle.rLights.blr.a then
					self.vehicle:setBlinkerLState(false);
					self.vehicle:setBlinkerRState(false);
				else
					self.vehicle:setBlinkerLState(false);
					self.vehicle:setBlinkerRState(true);
				end;
			end;
		end;
	end;
	
--	if self.vehicle ~= nil then
--       if self.event == "toggleMotorIgnition" then
--			if self.vehicle.isMotorStarted then
--				self.vehicle:setManualIgnitionMode(false, noEventSend);
--			else
--				self.vehicle:setManualIgnitionMode(true, noEventSend);
--			end;
--		end;	
--	end;
	if self.event == "toggleLeftIndicator" then
		if self.vehicle ~= nil then
			if not self.vehicle.rLights.blw.a then
				if self.vehicle.rLights.bll.a then
					self.vehicle:setBlinkerLState(false);
					self.vehicle:setBlinkerRState(false);
				else
					self.vehicle:setBlinkerLState(true);
					self.vehicle:setBlinkerRState(false);
				end;
			end;
		end;
	end;
	
	if self.event == "toggleSosi" then
		if self.vehicle ~= nil then
			local i = 1;
			local j = 2;
			local k = 3;
			local l = 4;
			local m = 5;
			if self.vehicle.B3.strobe[i].a then
				self.vehicle:setState("strobe:"..i, false);
				self.vehicle:setState("strobe:"..j, false);
				self.vehicle:setState("strobe:"..k, false);
				self.vehicle:setState("strobe:"..l, false);
				self.vehicle:setState("strobe:"..m, false);
				self.vehicle:toggle(i,false);
				self.vehicle:toggle(j,false);
				self.vehicle:toggle(k,false);
			else
				self.vehicle:setState("strobe:"..i, true);
				self.vehicle:setState("strobe:"..j, true);
				self.vehicle:setState("strobe:"..k, true);
				self.vehicle:setState("strobe:"..l, true);
				self.vehicle:setState("strobe:"..m, true);
				self.vehicle:toggle(i,false);
				self.vehicle:toggle(j,false);
				self.vehicle:toggle(k,true);
			end;
		end;
	end;
	
	if self.event == "togglePress" then
		if self.vehicle ~= nil then
			local i = 1;
			local j = 2;
			local k = 3;
			if self.vehicle.B3.strobe[i].a then
				self.vehicle:toggle(i,false);
				self.vehicle:toggle(j,false);
				self.vehicle:toggle(k,true);
			else
				self.vehicle:toggle(i,false);
				self.vehicle:toggle(j,false);
				self.vehicle:toggle(k,false);
			end;
		end;
	end;
	
	if self.event == "toggleFrontBeacon" then
		if self.vehicle ~= nil then
			local i = 1;
			local j = 2;
			if self.vehicle.B3.strobe[i].a then
				self.vehicle:setState("strobe:"..i, false);
				self.vehicle:setState("strobe:"..j, false);
			else
				self.vehicle:setState("strobe:"..i, true);
				self.vehicle:setState("strobe:"..j, true);
			end;
		end;
	end;
	
end;

function Button:onEnter(dt)
	InteractiveComponentInterface.onEnter(self, dt);
end;

function Button:onExit(dt)
	InteractiveComponentInterface.onExit(self, dt);
end;

function Button:setActive()
	InteractiveComponentInterface.setActive(self, isActive);
end;

function Button:setVisible(isVisible)
	InteractiveComponentInterface.setVisible(self, isVisible);
end;